@@ -1505,8 +1505,107 @@ setMethod(
 ## "ip.hash<-"
 ##
 ##
-##
 setMethod(
+  "ip.index"
+  ## 
+  , signature(table = "IPv4r")
+  ##
+  , function(table, overlap=FALSE,...){
+    ##
+    bsearch <- function(x=NULL, nomatch=NA_integer_, value=F,...){
+      ##
+      if( is.null(x) ) x <- table
+      ##
+      ## "polymorphisme"
+      ##
+      tb.clnm <- tolower(class(table))
+      ##
+      x.clnm <- if( ( kl <-class(x)) %in% c('IPv4', 'IPv4r' ) ){
+        tolower(kl)
+      }else stop('bsearch not implemented for object of class ', kl , ' and table ', class(table))
+      ##
+      midx <- .Call(
+          ## "dispatch"
+          sprintf('Rip_bsearch_%s_in_%s_0', x.clnm, tb.clnm)
+          ##
+          , x 
+          , table
+          , idx
+          , nomatch
+      )+1L
+      ##
+      if( value )  return(table[midx]) ## return(x[midx])##
+      ##
+      midx
+    }
+    ##
+    bsearch.overlap <- function(x=NULL,nomatch=NA_integer_,value=F,...){  
+      ##
+      nullx <- if( is.null(x) ){x <- table; T} else F
+      ##
+      ## "polymorphisme"
+      ##
+      ##
+      x.clnm <- if( ( kl <-class(x)) %in% c('IPv4', 'IPv4r' ) ){
+        tolower(kl)
+      }else stop('bsearch with overlap not implemented for object of class ', kl , ' and table ', class(table))    
+      ##
+      m <- .Call(
+          ## "dispatch"
+          if( x.clnm=='ipv4') "Rip_bsearch_intvTree_ipv4_in_ipv4r_0" else "Rip_bsearch_intvTree_ipv4r_overlap_ipv4r_0"
+          ## 
+          , x 
+          , table[idx+1L]
+          , idx
+          , minmxIdx
+          , NA_integer_
+      )
+      ## 
+      if( value ){
+        ##
+        return(
+          data.frame(
+            rep(m, diff(attr(m, 'ptr')))
+            , table[attr(m, 'midx')+1L]
+          ) |> `colnames<-`(c(
+              if(!nullx) deparse(substitute(x)) else "table"
+              , "m"
+          ))
+        )
+      }
+      ##
+      attr(m, "midx") <- attr(m, "midx") + 1L
+      ##
+      m
+    }
+    ## 
+    if( !length(table) ) stop("empty table")
+    ##
+    table <- table[!(na<-is.na(table))]
+    ##
+    if( (na <- sum(na) ) ) warning("removing ", na, " NA from table")
+    ## 
+    idx <- order( ## ip.order
+      table 
+      ##, na.last= NA ## rm ?
+    ) - 1L
+    ##
+    minmxIdx <- if(overlap){
+      ##
+      .Call(
+        "Rip_bsearch_intvTree_ipv4r_index_0"
+        , table[idx+1L]
+        , idx
+      )
+    } 
+    ##
+    return(
+      if( !overlap ) bsearch else bsearch.overlap
+    )
+  }
+)
+##
+if(F) setMethod(
   "ip.index"
   ## 
   , signature(table = "IPv4r")
